Crate tidos_macro

Crate tidos_macro 

Macros

head
Adds body contents to the head of the page
page
Similar to the view, however it will also render the templates into a page context.
scoped_css
CSS file to include in the head of the body. Macro returns a CSS class you can use in your view template
view
Turn your template into a usable string